%define with_spring2 1
%define with_maven2 0
Name:           xbean
Version:        3.7
BuildArch:      noarch

Release:        %mkrel 9
Summary:        Java plugin based web server

Group:          Development/Java
License:        ASL 2.0
URL:            http://geronimo.apache.org/xbean/

# unfortunately no source/binary releases are being made lately, just
# tags in repos and binary releases in maven repositories
# svn export http://svn.apache.org/repos/asf/geronimo/xbean/tags/xbean-3.7
# tar caf xbean-3.7.tar.xz xbean-3.7
Source0:        xbean-%{version}.tar.xz
Source1:        xbean.depmap

Patch0:         pom-%{version}.patch
Patch1:         pom-3.7-enable-finder.patch
Patch2:         xbean-3.7-enable-spring-modules.patch

BuildRequires:  java-devel
BuildRequires:  apache-commons-beanutils
BuildRequires:  apache-commons-logging
BuildRequires:  mx4j
BuildRequires:  objectweb-asm
BuildRequires:  ant
BuildRequires:  qdox
BuildRequires:  slf4j
%if %with_spring2
BuildRequires:  spring2-beans
BuildRequires:  spring2-context
BuildRequires:  spring2-web
%endif
BuildRequires:  felix-osgi-core >= 1.4.0
BuildRequires:  maven
BuildRequires:  maven-plugin-bundle
BuildRequires:  maven-antrun-plugin
BuildRequires:  maven-compiler-plugin
BuildRequires:  maven-idea-plugin
BuildRequires:  maven-install-plugin
BuildRequires:  maven-javadoc-plugin
BuildRequires:  maven-resources-plugin
BuildRequires:  maven-surefire-maven-plugin
BuildRequires:  maven-site-plugin
BuildRequires:  maven-shade-plugin

Requires:       java
Requires:       objectweb-asm
Requires:       apache-commons-logging
%if %with_spring2
Requires:       spring2-beans
Requires:       spring2-context
Requires:       spring2-web
%endif


%description
The goal of XBean project is to create a plugin based server
analogous to Eclipse being a plugin based IDE. XBean will be able to
discover, download and install server plugins from an Internet based
repository. In addition, we include support for multiple IoC systems,
support for running with no IoC system, JMX without JMX code,
lifecycle and class loader management, and a rock solid Spring
integration.

%package        javadoc
Summary:        API documentation for %{name}
Group:          Development/Java
Requires:       jpackage-utils

%description    javadoc
%{summary}.

%prep
%setup -q
# build failing on this due to doxia-sitetools problems
rm src/site/site.xml

# removes dependency on springframework and prevents building of
# modules depending on it. If other modules are required,
# springframework will have to be brought in first

%patch0 -p1
%patch1 -p0
%if %with_spring2
%patch2 -p1
%endif

# Fix dependency on xbean-asm-shaded to original objectweb-asm
sed -i 's/org.apache.xbean.asm/org.objectweb.asm/' \
    xbean-reflect/src/main/java/org/apache/xbean/recipe/XbeanAsmParameterNameLoader.java

%build
%if %with_maven2
  export MAVEN_REPO_LOCAL=$(pwd)/.m2/repository
  mvn-jpp -e \
    -Dmaven.test.skip=true \
    -Dmaven.repo.local=$MAVEN_REPO_LOCAL \
    -Dmaven2.jpp.depmap.file="%{SOURCE1}" \
    install javadoc:aggregate
%else
  mvn-rpmbuild -e \
    -Dmaven.local.depmap.file=%{SOURCE1} \
    -Dmaven.test.skip=true \
    install javadoc:aggregate
%endif
%install
# for every module we want to be built
for sub in bundleutils finder reflect naming classpath; do
# install jar
    install -Dpm 644 %{name}-${sub}/target/%{name}-${sub}-%{version}.jar \
            $RPM_BUILD_ROOT/%{_javadir}/xbean/%{name}-${sub}.jar;

# intall pom
    install -Dpm 644 %{name}-${sub}/pom.xml $RPM_BUILD_ROOT/%{_mavenpomdir}/JPP.%{name}-%{name}-${sub}.pom

# maven depmap
    %add_to_maven_depmap org.apache.xbean %{name}-${sub} %{version} JPP/%{name} %{name}-${sub}
done

%if %with_spring2
for sub in classloader spring; do
    install -pm 644 %{name}-${sub}/target/%{name}-${sub}-%{version}.jar \
            $RPM_BUILD_ROOT/%{_javadir}/xbean/%{name}-${sub}.jar;
    install -pm 644 %{name}-${sub}/pom.xml $RPM_BUILD_ROOT/%{_mavenpomdir}/JPP.%{name}-%{name}-${sub}.pom
    %add_to_maven_depmap org.apache.xbean %{name}-${sub} %{version} JPP/%{name} %{name}-${sub}
done
  install -pm 644 maven-xbean-plugin/target/maven-xbean-plugin-%{version}.jar \
    $RPM_BUILD_ROOT/%{_javadir}/xbean/%{name}-plugin.jar
  install -pm 644 maven-xbean-plugin/pom.xml $RPM_BUILD_ROOT/%{_mavenpomdir}/JPP.%{name}-%{name}-plugin.pom
  %add_to_maven_depmap org.apache.xbean maven-%{name}-plugin %{version} JPP/%{name} %{name}-plugin
%endif


install -d -m 755 $RPM_BUILD_ROOT%{_javadocdir}/%{name}
cp -pr target/site/apidocs/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}

# parent pom
install -pm 644 pom.xml $RPM_BUILD_ROOT/%{_mavenpomdir}/JPP.%{name}-main.pom
%add_to_maven_depmap org.apache.xbean %{name} %{version} JPP/%{name} main

# UGLY hack to fix maven without 2 rebuilds
install -dm 755 $RPM_BUILD_ROOT%{_datadir}/maven/lib/ext


%pre javadoc
# workaround for rpm bug, can be removed in F-17
[ $1 -gt 1 ] && [ -L %{_javadocdir}/%{name} ] && \
rm -rf $(readlink -f %{_javadocdir}/%{name}) %{_javadocdir}/%{name} || :

%post
%update_maven_depmap

%postun
%update_maven_depmap

%files
%defattr(-,root,root,-)
%doc LICENSE NOTICE
%{_mavenpomdir}/*.pom
%{_mavendepmapfragdir}/%{name}
%{_javadir}/%{name}
%{_datadir}/maven/lib/ext

%files javadoc
%defattr(-,root,root,-)
%doc LICENSE
%{_javadocdir}/%{name}



%changelog

* Thu Sep 22 2011 gil <gil> 3.7-9.mga2
+ Revision: 146742
- rebuilt with spring2 support (added new modules: classloader spring maven-xbean-plugin)

* Wed Jul 20 2011 dmorgan <dmorgan> 3.7-8.mga2
+ Revision: 127124
- Remove unused hack

  + gil <gil>
    - add patch1
    - add patch1

* Thu Apr 28 2011 dmorgan <dmorgan> 3.7-7.mga1
+ Revision: 93151
- Rebuild after bootstrapping
- imported package xbean


* Fri Mar  4 2011 Stanislav Ochotnicky <sochotnicky@redhat.com> - 3.7-6
- Add comment for removing javadoc
- Fix maven 3 build

* Mon Feb 07 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.7-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Mon Dec  6 2010 Stanislav Ochotnicky <sochotnicky@redhat.com> - 3.7-4
- Fix pom filename (Resolves rhbz#655827)
- Add depmap for main pom file
- Fixes according to new guidelines (versionless jars, javadocs)

* Fri Jul 30 2010 Stanislav Ochotnicky <sochotnicky@redhat.com> - 3.7-3
- Use javadoc:aggregate to generate javadocs

* Fri Jul  9 2010 Stanislav Ochotnicky <sochotnicky@redhat.com> - 3.7-2
- Add license to javadoc subpackage

* Mon Jun 21 2010 Stanislav Ochotnicky <sochotnicky@redhat.com> - 3.7-1
- First release

